//
//  MapViewController.m
//  MapLocation
//
//  Created by 马云翠 on 16/9/27.
//  Copyright © 2016年 mayuncui. All rights reserved.
//

#import "MapViewController.h"
#import <MapKit/MapKit.h>
#import "ZKAnnotation.h"
@interface MapViewController ()<MKMapViewDelegate>
@property (weak, nonatomic) IBOutlet MKMapView *mapView;
@property ( nonatomic, strong) CLLocationManager *localtionManager;
@end

@implementation MapViewController

- (void)viewDidLoad {
    [super viewDidLoad];

    ZKAnnotation *annotation = [[ZKAnnotation alloc]init];
    annotation.coordinate = CLLocationCoordinate2DMake(39.9, 116.3);
    annotation.title = @"我是父标题";
    annotation.subTitle = @"我是子标题";
    
    //添加大头针到北京
    [self.mapView addAnnotation:annotation];
    
    
    //初始化localtion管理对象
    CLLocationManager *localtionManager = [[CLLocationManager alloc]init];
    self.localtionManager = localtionManager;
    
    //请求授权
    [localtionManager requestWhenInUseAuthorization];
    
    /*
     MKUserTrackingModeNone  不进行用户位置跟踪
     MKUserTrackingModeFollow  跟踪用户的位置变化
     MKUserTrackingModeFollowWithHeading  跟踪用户位置和方向变化
     */
    
    //设置用户的跟踪模式
    //self.mapView.userTrackingMode = MKUserTrackingModeFollow;
   
    /*
     MKMapTypeStandard  标准地图
     MKMapTypeSatellite    卫星地图
     MKMapTypeHybrid      鸟瞰地图
     MKMapTypeSatelliteFlyover
     MKMapTypeHybridFlyover
     */
    
    self.mapView.mapType = MKMapTypeStandard;
    //实时交通状况
    self.mapView.showsTraffic = YES;
    //设置代理
    self.mapView.delegate = self;
    
   
}

//MARK: - 跟踪到用户位置调用该方法
- (void)mapView:(MKMapView *)mapView didUpdateUserLocation:(MKUserLocation *)userLocation{
    //创建用户编码
    CLGeocoder *geocoder = [CLGeocoder new];
    //反地理编码
    [geocoder reverseGeocodeLocation:userLocation.location completionHandler:^(NSArray<CLPlacemark *> * _Nullable placemarks, NSError * _Nullable error) {
        if (error != nil || placemarks.count == 0) {
            return ;
        }
        //获取地标
        CLPlacemark *placeMark = [placemarks firstObject];
        //设置标题
        userLocation.title = placeMark.locality;
        //设置子标题
        userLocation.subtitle = placeMark.name;
        
    }];
}
//回到当前位置
- (IBAction)backCurrentLocation:(id)sender {
    
    MKCoordinateSpan span = MKCoordinateSpanMake(0.021251, 0.016093);
    
    [self.mapView setRegion:MKCoordinateRegionMake(self.mapView.userLocation.coordinate, span) animated:YES];
}
//当区域改变时调用
- (void)mapView:(MKMapView *)mapView regionDidChangeAnimated:(BOOL)animated{
    
    //获取系统默认定位的经纬度跨度
    NSLog(@"纬度跨度：%f, 经度跨度：%f", mapView.region.span.latitudeDelta, mapView.region.span.longitudeDelta);
}
//缩小地图
- (IBAction)minMapView:(id)sender {
    
    //获取纬度并放大一倍
    CGFloat latitudeDelta = self.mapView.region.span.latitudeDelta * 2;
    //获取纬度并放大一倍
    CGFloat longitudeDelta = self.mapView.region.span.longitudeDelta * 2;
    //经纬度跨度
    MKCoordinateSpan span = MKCoordinateSpanMake(latitudeDelta, longitudeDelta);
    //设置当前区域
    MKCoordinateRegion region = MKCoordinateRegionMake(self.mapView.centerCoordinate, span);
    
    [self.mapView setRegion:region animated:YES];
}
//放大地图
- (IBAction)maxMapView:(id)sender {
    
    //获取纬度并缩小一倍
    CGFloat latitudeDelta = self.mapView.region.span.latitudeDelta * 0.5;
    //获取经度并缩小一倍
    CGFloat longitudeDelta = self.mapView.region.span.longitudeDelta * 0.5;
    //经纬度跨度
    MKCoordinateSpan span = MKCoordinateSpanMake(latitudeDelta, longitudeDelta);
    //设置当前区域
    MKCoordinateRegion region = MKCoordinateRegionMake(self.mapView.centerCoordinate, span);
    
    [self.mapView setRegion:region animated:YES];
}


//当点击屏幕时调用
- (void)touchesBegan:(NSSet<UITouch *> *)touches withEvent:(UIEvent *)event{
    
    //获取用户点击的位置
    CGPoint point = [[touches anyObject] locationInView:self.mapView];
    //将具体的位置转换为经纬度
    CLLocationCoordinate2D coordinate = [self.mapView convertPoint:point toCoordinateFromView:self.mapView];
    
    //添加大头针
    ZKAnnotation *annotation = [ZKAnnotation new];
    annotation.coordinate = coordinate;
    
    //反地理编码
    CLGeocoder *geocoder = [CLGeocoder new];
    CLLocation *location = [[CLLocation alloc]initWithLatitude:coordinate.latitude longitude:coordinate.longitude];
    [geocoder reverseGeocodeLocation:location completionHandler:^(NSArray<CLPlacemark *> * _Nullable placemarks, NSError * _Nullable error) {
        if (error != nil && placemarks.count == 0) {
            return ;
        }
        
        //获取地标信息
        CLPlacemark *placemark = [placemarks firstObject];
        //获取父标题名称
        annotation.title = placemark.locality;
        //获取子标题名称
        annotation.subTitle = placemark.name;
        
        //添加大头针到地图
        [self.mapView addAnnotation:annotation];
        
    }];
}

//创建大头针时调用
- (MKAnnotationView *)mapView:(MKMapView *)mapView viewForAnnotation:(id<MKAnnotation>)annotation{
    //如果返回空，代表大头针样式交由系统去管理
    if ([annotation isKindOfClass:[MKUserLocation class]]) {
        return nil;
    }
    
    static NSString *ID = @"annotation";
    // MKAnnotationView 默认没有界面  可以显示图片
    // MKPinAnnotationView有界面      默认不能显示图片
    MKPinAnnotationView *annotationView = (MKPinAnnotationView *)[mapView dequeueReusableAnnotationViewWithIdentifier:ID];
    if (annotationView == nil) {
        annotationView = [[MKPinAnnotationView alloc]initWithAnnotation:annotation reuseIdentifier:ID];
        //设置大头针颜色
        annotationView.pinTintColor = [UIColor redColor];
        //设置动画掉落的效果
        annotationView.animatesDrop = YES;
        //显示详情
        annotationView.canShowCallout = YES;
    }
    return annotationView;
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

/*
#pragma mark - Navigation

// In a storyboard-based application, you will often want to do a little preparation before navigation
- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender {
    // Get the new view controller using [segue destinationViewController].
    // Pass the selected object to the new view controller.
}
*/

@end
