//
//  ViewController.m
//  MapLocation
//
//  Created by 马云翠 on 16/9/26.
//  Copyright © 2016年 mayuncui. All rights reserved.
//

#import "ViewController.h"
#import <CoreLocation/CoreLocation.h>
#import "MapViewController.h"
@interface ViewController ()<CLLocationManagerDelegate, UITextFieldDelegate>
@property (nonatomic, strong) CLLocationManager *localtionManager;
//地址
@property (weak, nonatomic) IBOutlet UITextField *addressTF;
//经度
@property (weak, nonatomic) IBOutlet UITextField *longitudeTextField;
//纬度
@property (weak, nonatomic) IBOutlet UITextField *latitudeTextField;
//详细地址
@property (weak, nonatomic) IBOutlet UITextView *textView;



@end

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];

    //初始化localtionManager管理器对象
    CLLocationManager *manager = [[CLLocationManager alloc]init];
    self.localtionManager = manager;
    
    //判断当前设备定位服务是否打开
    if (![CLLocationManager locationServicesEnabled]) {
        NSLog(@"设备尚未打开定位服务");
    }
    
    //判断当前版本是否大于或等于8.0
    if ([UIDevice currentDevice].systemVersion.floatValue >= 8.0) {
        //持续授权
        [manager requestAlwaysAuthorization];
        //使用期间授权
        [manager requestWhenInUseAuthorization];
    }
    
    //iOS9之后新特性
//    if ([UIDevice currentDevice].systemVersion.floatValue > 9.0) {
//        //是否允许后台定位
//        manager.allowsBackgroundLocationUpdates = YES;
//    }
    
    //设置代理
    manager.delegate = self;
    //设置定位精度
    manager.desiredAccuracy = kCLLocationAccuracyBest;
    //设置定位的频率，。这里我们设置精度为10，也就是10米定位一次
    CLLocationDistance distance = 10;
    //给精度赋值
    manager.distanceFilter = distance;
    
    //开始定位
    [manager startUpdatingLocation];
    //比较两点距离
    [self compareDistance];
}

//MARK: - 当位置发生改变时调用（上面设置的10米，也就是当位置改变大于10米的时候这个方法就会调用）
- (void)locationManager:(CLLocationManager *)manager didUpdateLocations:(NSArray<CLLocation *> *)locations{
    //取出第一个位置
    CLLocation *localtion = [locations firstObject];
    NSLog(@"%@", localtion.timestamp);
    //位置坐标
    CLLocationCoordinate2D coordinate = localtion.coordinate;
    
    NSLog(@"经度： %f, 纬度： %f， 海拔：%f， 航向：%f, 速度： %f", coordinate.longitude, coordinate.latitude, localtion.altitude, localtion.course, localtion.speed);
    //如果不需要实时定位，使用完即关闭定位功能
   // [_localtionManager stopUpdatingLocation];
}


//MARK: - 比较两地之间距离（直线距离）
- (void)compareDistance{
    //北京（116.3， 39.9）
    CLLocation *localtion1 = [[CLLocation alloc]initWithLatitude: 39.9 longitude:116.3];
    //郑州(113.42, 34.44)
    CLLocation *localtion2 = [[CLLocation alloc]initWithLatitude:34.44 longitude:113.42];
    //比较两地距离
    CLLocationDistance distance = [localtion1 distanceFromLocation:localtion2];
    //单位是m/s, 所以这里除以1000
    NSLog(@"北京距离郑州的距离是：%f", distance/1000);
}

//MARK: - 地理编码与反地理编码
//地理编码:根据地址获得相应的经纬度以及详细信息
//反地理编码:根据经纬度获取详细的地址信息(比如:省市、街区、楼层、门牌等信息)
//地理编码
- (IBAction)genocoder:(UIButton *)sender {
    //创建编码对象
    CLGeocoder *geocoder = [[CLGeocoder alloc]init];
    //判断是否空
    if (self.addressTF.text.length == 0) {
        return;
    }
    [geocoder geocodeAddressString:self.addressTF.text completionHandler:^(NSArray<CLPlacemark *> * _Nullable placemarks, NSError * _Nullable error) {
        if (error != nil || placemarks.count == 0) {
            return ;
        }
        //创建placeMarks对象
        CLPlacemark *placeMark = [placemarks firstObject];
        //赋值经度
        self.longitudeTextField.text = [NSString stringWithFormat:@"%f", placeMark.location.coordinate.longitude];
        //赋值纬度
        self.latitudeTextField.text = [NSString stringWithFormat:@"%f", placeMark.location.coordinate.latitude];
        //赋值详细地址
        self.textView.text = placeMark.name;
    }];
}
//反地理编码
- (IBAction)AntiEncoder:(UIButton *)sender {
    //创建地理编码对象
    CLGeocoder *geocoder = [[CLGeocoder alloc]init];
    //创建位置
    CLLocation *localtion = [[CLLocation alloc]initWithLatitude:[self.latitudeTextField.text floatValue] longitude:[self.longitudeTextField.text floatValue]];
    //反地理编码
    [geocoder reverseGeocodeLocation:localtion completionHandler:^(NSArray<CLPlacemark *> * _Nullable placemarks, NSError * _Nullable error) {
        if (error != nil ||  placemarks.count == 0) {
            return ;
        }
        
        for (CLPlacemark *placeMark in placemarks) {
            //赋值详细地址
            self.textView.text = placeMark.name;
        }
    }];
}

- (IBAction)pushToMapVC:(UIButton *)sender {
//    MapViewController *mapVC = [MapViewController new];
//    [self.navigationController pushViewController:mapVC animated:YES];
}


- (void)touchesBegan:(NSSet<UITouch *> *)touches withEvent:(UIEvent *)event{
    [self.view endEditing:YES];
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}


@end
